// $Id: placeholder.cc,v 1.12 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1999  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "WriterBase.hh"

class Placeholder : public WriterBase
{public:
	typedef WriterBase Parent;
	virtual const std::string TypeName(const Widget &w) const
	{  return ""; }
	virtual const std::string IncludeName(const Widget &w) const
	{  return ""; }
	Placeholder();
	virtual void GHDeclaration(const Widget &w, CxxFile &f) const
	{}
#if 0 // not needed
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
#endif	
};

static Placeholder Placeholder;

Placeholder::Placeholder()
{  Writer["Placeholder"]=this;
}
